==> autogen-5.7.3.tar.gz: autogen-5.7.3/autoopts/proto.h <==
/* -*- buffer-read-only: t -*- vi: set ro:
 *
 * Prototypes for autoopts
 * Generated Sat Oct  8 11:13:46 PDT 2005
 */
#ifndef AUTOOPTS_PROTO_H_GUARD
#define AUTOOPTS_PROTO_H_GUARD
#ifndef LOCAL
#  define LOCAL extern
#  define REDEF_LOCAL 1
#else
#  undef  REDEF_LOCAL
#endif
/*
 *  Extracted from autoopts.c
 */
LOCAL tSuccess
handleOption( tOptions* pOpts, tOptState* pOptState );

LOCAL tSuccess
longOptionFind( tOptions* pOpts, char* pzOptName, tOptState* pOptState );

LOCAL tSuccess
shortOptionFind( tOptions* pOpts, tUC optValue, tOptState* pOptState );

LOCAL tSuccess
doImmediateOpts( tOptions* pOpts );

LOCAL tSuccess
doRegularOpts( tOptions* pOpts );

/*
 *  Extracted from configfile.c
 */
LOCAL void
internalFileLoad( tOptions* pOpts );

LOCAL char*
parseAttributes(
    tOptions*           pOpts,
    char*               pzText,
    tOptionLoadMode*    pMode,
    tOptionValue*       pType );

LOCAL tSuccess
validateOptionsStruct( tOptions* pOpts, const char* pzProgram );

/*
 *  Extracted from environment.c
 */
LOCAL void
doPrognameEnv( tOptions* pOpts, teEnvPresetType type );

LOCAL void
doEnvPresets( tOptions* pOpts, teEnvPresetType type );

/*
 *  Extracted from load.c
 */
LOCAL void
mungeString( char* pzTxt, tOptionLoadMode mode );

LOCAL void
loadOptionLine(
    tOptions*   pOpts,
    tOptState*  pOS,
    char*       pzLine,
    tDirection  direction,
    tOptionLoadMode   load_mode );

/*
 *  Extracted from sort.c
 */
LOCAL void
optionSort( tOptions* pOpts );

/*
 *  Extracted from stack.c
 */
LOCAL void
addArgListEntry( void** ppAL, void* entry );

#ifdef REDEF_LOCAL
#  undef LOCAL
#  define LOCAL
#endif

#endif /* AUTOOPTS_PROTO_H_GUARD */

==> autogen-5.8.tar.gz: autogen-5.8/autoopts/proto.h <==
/* -*- buffer-read-only: t -*- vi: set ro:
 *
 * Prototypes for autoopts
 * Generated Thu Dec 15 15:11:46 PST 2005
 */
#ifndef AUTOOPTS_PROTO_H_GUARD
#define AUTOOPTS_PROTO_H_GUARD
#ifndef LOCAL
#  define LOCAL extern
#  define REDEF_LOCAL 1
#else
#  undef  REDEF_LOCAL
#endif
/*
 *  Extracted from autoopts.c
 */
LOCAL tSuccess
handleOption( tOptions* pOpts, tOptState* pOptState );

LOCAL tSuccess
longOptionFind( tOptions* pOpts, char* pzOptName, tOptState* pOptState );

LOCAL tSuccess
shortOptionFind( tOptions* pOpts, tAoUC optValue, tOptState* pOptState );

LOCAL tSuccess
doImmediateOpts( tOptions* pOpts );

LOCAL tSuccess
doRegularOpts( tOptions* pOpts );

/*
 *  Extracted from configfile.c
 */
LOCAL void
internalFileLoad( tOptions* pOpts );

LOCAL char*
parseAttributes(
    tOptions*           pOpts,
    char*               pzText,
    tOptionLoadMode*    pMode,
    tOptionValue*       pType );

LOCAL tSuccess
validateOptionsStruct( tOptions* pOpts, const char* pzProgram );

/*
 *  Extracted from environment.c
 */
LOCAL void
doPrognameEnv( tOptions* pOpts, teEnvPresetType type );

LOCAL void
doEnvPresets( tOptions* pOpts, teEnvPresetType type );

/*
 *  Extracted from load.c
 */
LOCAL void
mungeString( char* pzTxt, tOptionLoadMode mode );

LOCAL void
loadOptionLine(
    tOptions*   pOpts,
    tOptState*  pOS,
    char*       pzLine,
    tDirection  direction,
    tOptionLoadMode   load_mode );

/*
 *  Extracted from sort.c
 */
LOCAL void
optionSort( tOptions* pOpts );

/*
 *  Extracted from stack.c
 */
LOCAL void
addArgListEntry( void** ppAL, void* entry );

#ifdef REDEF_LOCAL
#  undef LOCAL
#  define LOCAL
#endif

#endif /* AUTOOPTS_PROTO_H_GUARD */
